Package: rfacebookstat
Type: Package
Title: Load Data from Facebook API Marketing
Version: 2.16.1
Authors@R: 
    c(person(given  = "Alexey",
             family = "Seleznev",
             role   = c("aut", "cre"),
             email  = "selesnow@gmail.com",
             comment = c(ORCID = "0000-0003-0410-7385")))
Maintainer: Alexey Seleznev <selesnow@gmail.com>
Description: Load data by campaigns, ads, ad sets and insights, ad account and business manager 
    from Facebook Marketing API into R. For more details see official documents by Facebook 
    Marketing API <https://developers.facebook.com/documentation/ads-commerce/marketing-api>.
Depends: R (>= 4.1.0)
BugReports: https://github.com/selesnow/rfacebookstat/issues
Imports: httr, httr2, jsonlite, dplyr, purrr, tidyr (>= 1.0.0),
        stringr, tidyselect, pbapply
URL: https://selesnow.github.io/rfacebookstat/,
        https://www.youtube.com/playlist?list=PLD2LDq8edf4pItOb-vZTG5AXZK2niJ8_R
License: MIT + file LICENSE
Suggests: knitr, rmarkdown
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-08-25 10:47:54 UTC; User
Author: Alexey Seleznev [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0410-7385>)
Repository: CRAN
Date/Publication: 2026-08-25 11:10:02 UTC
Built: R 4.5.2; ; 2026-08-25 13:01:14 UTC; unix
