export(fbAuth)
export(fbGetToken)
export(fbGetBusinessManagers)
export(fbGetAdAccounts)
export(fbGetUserAdAccounts)
export(fbGetAdAccountUsers)
export(fbUpdateAdAccountUsers)
export(fbGetAdAccountsConversions)
export(fbDeleteAdAccountUsers)
export(fbGetPages)
export(fbGetApps)
export(fbGetAdAccountUsersPermissions)
export(fbGetLongTimeToken)
export(fbGetMarketingStat)
export(fbGetAdSets)
export(fbGetAdCreative)
export(fbGetAds)
export(fbGetCampaigns)
export(fbGetAdVideos)
export(fbGetBusinessUserAdAccounts)
export(fbGetBusinessManagersUsers)
export(fbGetCatalogs)
export(fbGetSettings)
export(fbGetCostData)
export(fbGetLogins)
export(fbSetUsername)
export(fbSetAccount)
export(fbSetBusinessId)
export(fbSetTokenPath)
export(fbSetApiVersion)
export(fbGetAdAccountCustomAudiences)

importFrom(jsonlite, fromJSON)
importFrom(jsonlite, toJSON)
importFrom(jsonlite, validate)
importFrom(httr, GET)
importFrom(httr, POST)
importFrom(httr, DELETE)
importFrom(httr, content)
importFrom(httr, headers)
importFrom(httr, stop_for_status)
importFrom(httr, status_code)
importFrom(dplyr, bind_rows)
importFrom(dplyr, bind_cols)
importFrom(dplyr, group_by)
importFrom(dplyr, summarise)
importFrom(dplyr, mutate)
importFrom(dplyr, select)
importFrom(dplyr, select_if)
importFrom(dplyr, "%>%")
importFrom(dplyr, tibble)
importFrom(dplyr, left_join)
importFrom(dplyr, mutate_if)
importFrom(dplyr, rename)
importFrom(dplyr, summarise_at)
importFrom(dplyr, ungroup)
importFrom(dplyr, rowwise)
importFrom(purrr, map)
importFrom(purrr, map_df)
importFrom(purrr, flatten)
importFrom(tidyr, spread)
importFrom(tidyr, pivot_wider)
importFrom(tidyr, pivot_longer)
importFrom(tidyr, unnest_wider)
importFrom(tidyr, unnest_longer)
importFrom(tidyr, replace_na)
importFrom(tidyr, unite)
importFrom(tidyselect, matches)
importFrom(stringr, str_interp)
importFrom(stringr, str_glue)
importFrom(stringr, str_split)
importFrom(stringr, str_c)
importFrom(stringr, str_remove_all)
importFrom(stringr, str_remove)
importFrom(stringr, str_replace)
importFrom(utils, browseURL, setTxtProgressBar, txtProgressBar)
importFrom(stats, setNames)
importFrom(pbapply, pblapply)
import(httr2)

S3method(print, fb_access_token)
S3method(print, fblimits)
S3method(fbAction, default)

