---
title: "3. Loadind click and cost data from Facebook into Google Analytics"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{3. Loadind click and cost data from Facebook into Google Analytics}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  eval=FALSE,
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup}
library(rfacebookstat)
```


Начиная с версии `rfacebookstat 2.1.0` в пакет была добавлена функция `fbGetCostData()`, которая позволяет вам получить данные о расходах для дальнейшей их загрузки в Google Analytics.

## Создаём набор данных в Google Analytics
Изначально вам необходимо создать набор данных в Google Analytics.

1. Заходим в панель администратора
2. В области ресурс выбираем пункт "Импорт данных"

![Панель администратора](http://img.netpeak.ua/alsey/159056878065_kiss_43kb.png)

3. Нажимае **Создать / Create**
4. Среды предложенных вариантов выбираем **Данные о расходах / Cost Data**

![Выбираем тип набора данных](http://img.netpeak.ua/alsey/159056895184_kiss_45kb.png)

5. Задаём имя набора данных
6. Выбираем из выпадающего списка представления, в которые будут импортироваться данные о расодах

![Выбираем представления](http://img.netpeak.ua/alsey/159056902310_kiss_20kb.png)

7. Настраиваем схему данных и выбираем перезаписывать данные если они соответвуют уже существующим строкам *Owerwrite*

![Настраиваем схему данных](http://img.netpeak.ua/alsey/159056941892_kiss_43kb.png)

8. Жмём сохранить.

Далее в интерфейсе появится созданный набор данных.

![Созданный набор данных](http://img.netpeak.ua/alsey/159056960727_kiss_11kb.png)

В дальнейшем нам понадобится его идентификаторв.

## Запрашиваем данные о расхода из рекламного кабинета Facebook
Далее мы можем запросить данные о расходах из любого аккаунта к которому у нас есть доступ, и с помощью пакета `googleAnalyticsR` загрузить их в созданный источник данных.

```{r}
library(rfacebookstat)
library(googleAnalyticsR)

# fb options
options(rfacebookstat.username = 'your_facebook_username')

# auth
fbAuth()
ga_auth(email = "google_analytics@gmail.com")

# read data from facebook
cost_data <- fbGetCostData(accounts_id = 1111111,
                           date_start  = '2020-03-01',
                           date_stop   = '2020-03-10',
                           utm_source  = 'fb', 
                           utm_medium  = 'cpc')

# upload into GA source
ga_custom_upload_file(accountId          = 2222222, 
                      webPropertyId      = "UA-2222222-1", 
                      customDataSourceId = 'M_XXXXX_Qudk-8g', 
                      cost_data)
```

Если вы всё сделали правильно в разделе "Manage Uploads" вы увидите загруженные данные, и сообщение о статусе загрузке.

![Раздел "Manage Uploads"](https://img.netpeak.ua/alsey/159057045311_kiss_11kb.png)

![Статус загрузки](https://img.netpeak.ua/alsey/159057047222_kiss_16kb.png)