\name{fbGetSettings}
\alias{fbGetSettings}

\title{Get settings.}
\description{Get settings of rfacebookstat package.}
\usage{
fbGetSettings()
}
\author{Alexey Seleznev}
\examples{
\dontrun{
fbGetSettings()
}
}
